/*
 *  js基本类型
 */
var jsType = {
    Undefined: 'Undefined',
    Null: 'Null',
    Object: 'Object',
    String: 'String',
    Array: 'Array',
    Function: 'Function',
    Date: 'Date',
    Boolean: 'Boolean',
    Number: 'Number',
    RegExp: 'RegExp'
};

/**
 *  常用正则
 **/
var reg = {
    formatReg: /(\{\d+\})/g,
    notEmpty: /\S+/,
    guid: /[\da-f]{8}-(?:[\da-f]{4}-){3}[\da-f]{12}/i,
    phone: /\d{11}/,
    token: /^[a-z\d]{32}$/i
};

/**
 *  常用辅助方法
 **/
var util = {
    isNull: function (obj) {
        return obj === null || typeof obj === 'undefined' || String(obj) === '(null)';
    },
    isEmpty: function (text) {
        return !(/\S+/.test(text));
    },
    isNullOrEmpty: function (obj) {
        return this.isNull(obj) || this.isEmpty(obj);
    },
    getType: function (obj) {
        var typeStr = Object.prototype.toString.call(obj);
        return typeStr.substring(8, typeStr.length - 1);
    },
    isObject: function (obj) {
        return this.getType(obj) === jsType.Object;
    },
    isString: function (obj) {
        return this.getType(obj) === jsType.String;
    },
    isArray: function (obj) {
        return this.getType(obj) === jsType.Array;
    },
    isFunction: function (obj) {
        return this.getType(obj) === jsType.Function;
    },
    isBoolean: function (obj) {
        return this.getType(obj) === jsType.Boolean;
    },
    trim: function (text) {
        return text.replace(/^\s+|\s+$/g, '');
    },
    toArray: function (args, index) {
        return Array.prototype.slice.call(args, index ? index : 0);
    },
    substring: function (text, number, addedText) {
        if (this.isNull(text)) {
            return '';
        }
        if (this.isNull(number) || text.length <= number) {
            return text;
        }
        if (this.isNull(addedText)) {
            addedText = '...';
        }

        return text.substr(0, number) + addedText;
    },
    formatString: function (text) {
        if (this.isNull(text)) {
            return '';
        }
        var array = text.match(reg.formatReg),
            args = this.toArray(arguments, 1);
        if (this.isNull(args)) {
            return text;
        }
        for (var i = 0; i < array.length; i++) {
            if (!this.isNull(args[i])) {
                text = text.replace(array[i], args[i]);
            } else {
                text = text.replace(array[i], '');
            }
        }
        return text;
    },
    delay: function (func, delay_time) {
        if (util.isNull(func)) {
            return;
        }
        setTimeout(func, delay_time || 0);
    },
    log: function (msg) {
        if (console) {
            console.log(msg)
        }
        $('#log').html('<p>' + msg + '</p>');
    },
    tip: function (msg) {
        if (util.isEmpty(msg)) {
            return;
        }
        util.log(msg);
    },
    getTime: function () {
        return new Date().getTime();
    }
};

var enums = {
    func_name: {
        get_data: 'get_data',
        migu_pay: 'migu_pay',
        migu_cancel_pay: 'migu_cancel_pay'
    }
};

//阅读参数
var data_params = {
    channelCode: 'M3G40001',
    sdkType: 'https',
    domain: 'https://ggs.manmeng168.com'
};

function local_log(msg) {
    //return;
    if ($('#log').find('p').length > 20) {
        $('#log').html('<p>' + msg + '</p>');
    } else {
        $('#log').append('<p>' + msg + '</p>');
    }
}

//客户端调通用H5
function callH5(base64) {
    let json_text = $.base64.decode(base64);
    local_log(json_text);
    let obj = eval('(' + json_text + ')');
    if (util.isNull(obj) || util.isEmpty(obj.func_name)) {
        return;
    }
    let payJson = {
        orderId: obj.orderId,
        channelCode: data_params.channelCode,
        productId: obj.productId,
        misidn: $.base64.encode(obj.mobile)
    };
    if (obj.func_name == enums.func_name.migu_pay) {
        payJson.actionType = 1;
        miguPay(payJson);
    } else if (obj.func_name == enums.func_name.migu_cancel_pay) {
        payJson.actionType = 2;
        miguCancelPay(payJson);
    }
}

//H5调用客户端
function callClient(obj) {
    obj.msg = encodeURIComponent(obj.msg);
    connectWebViewJavascriptBridge(function () {
        window.WebViewJavascriptBridge.callHandler(
            'callAndroid',
            obj,
            function (responseData) {
                local_log(responseData);
            }
        );
    });
}

function connectWebViewJavascriptBridge(callback) {
    if (window.WebViewJavascriptBridge) {
        callback(WebViewJavascriptBridge);
    } else {
        document.addEventListener('WebViewJavascriptBridgeReady', function () {
            callback(WebViewJavascriptBridge);
        }, false);
    }
}


//R业务
function init() {
    // android初始化
    connectWebViewJavascriptBridge(function (bridge) {
        bridge.init(function (message, responseCallback) {
            responseCallback();
        });

        bridge.registerHandler("callH5", function (data, responseCallback) {
            callH5(data);
            responseCallback();
        });
    });
    getData();
}

//初始化接口
function getData() {
    local_log('getData execute');
    window.MiguSdk.getData(data_params, function (resultCode, msg, authSessionId) {
        local_log('getData execute result: ' + resultCode + ',' + msg + ',' + authSessionId);
        callClient({
            result_code: resultCode,
            func_name: enums.func_name.get_data,
            msg: msg,
            auth_session_id: authSessionId
        });
    });

    // callClient({
    //     result_code: '0000',
    //     func_name: enums.func_name.get_data,
    //     msg: 'SUCCESS',
    //     auth_session_id: '123456'
    // });
}

//支付接口
function miguPay(payjson) {
    local_log('miguPay execute');
    window.MiguSdk.migupay(payjson, function (resultCode, msg, data) {
        local_log('miguPay execute result: ' + resultCode + ',' + msg + ',' + data + ',' + JSON.stringify(payjson));
        callClient({
            result_code: resultCode,
            func_name: enums.func_name.migu_pay,
            msg: msg,
            data: data
        });
    });

    // callClient({
    //     result_code: '0000',
    //     func_name: enums.func_name.migu_pay,
    //     msg: 'SUCCESS',
    //     data: JSON.stringify(payjson)
    // });
}

//取消支付接口
function miguCancelPay(payjson) {
    local_log('miguCancelPay');
    window.MiguSdk.migupay(payjson, function (resultCode, msg, data) {
        local_log('miguCancelPay execute result: ' + resultCode + ',' + msg + ',' + data + ',' + JSON.stringify(payjson));
        callClient({
            result_code: resultCode,
            func_name: enums.func_name.migu_cancel_pay,
            msg: msg,
            data: data
        });
    });

    // callClient({
    //     result_code: '0000',
    //     func_name: enums.func_name.migu_cancel_pay,
    //     msg: 'SUCCESS',
    //     data: JSON.stringify(payjson)
    // });
}

